==> analytics.js-integration-walkme-1.0.0.tgz: package/lib/index.js <==
'use strict';

/**
 * Module dependencies.
 */

var integration = require('@segment/analytics.js-integration');
var Identify = require('segmentio-facade').Identify;

/**
 * Expose `WalkMe`
 */

var WalkMe = module.exports = integration('WalkMe')
  .assumesPageview()
  .global('walkme')
  .option('walkmeGuid', '')
  .option('walkmeEnv', '')
  .option('walkmeLoadInIframe', false)
  .tag('<script src="https://cdn.walkme.com/users/{{ walkmeGuid }}{{ walkmeEnv }}/walkme_{{ walkmeGuid }}_https.js">')

/**
 * Initialize WalkMe
 *
 * @param {Facade} page
 */

WalkMe.prototype.initialize = function () {
  window._walkmeConfig = { smartLoad: true };

  if (this.options.walkmeLoadInIframe) {
    window.walkme_load_in_iframe = true;
  }

  var env = "\/" + (this.options.walkmeEnv && this.options.walkmeEnv.toLowerCase());

  if (!env || env == "\/" || env == "\/production") {
    env = "";
  }

  var _this = this;
  window.walkme_ready = function () {
    _this.ready()
  };

  this.load({
    walkmeGuid: this.options.walkmeGuid.toLowerCase(),
    walkmeEnv: env
  });

};

/**
 * Has the WalkMe library been loaded yet?
 *
 * @return {Boolean}
 */

WalkMe.prototype.loaded = function () {
  return !!window.WalkMeAPI;
};

/**
 * Identify.
 *
 * @api public
 * @param {Identify} identify
 */

WalkMe.prototype.identify = function (identify) {
  window._walkmeInternals.Segment = window._walkmeInternals.Segment || {}

  if (identify.userId()) {
    window._walkmeInternals.Segment.userId = String(identify.userId());
    window._walkmeInternals.Segment.isAnonUser = false;
  } else {
    window._walkmeInternals.Segment.userId = String(identify.anonymousId());
    window._walkmeInternals.Segment.isAnonUser = true;
  }

  window._walkmeInternals.Segment.email = identify.email();
  window._walkmeInternals.Segment.traits = identify.traits();

  window.WalkMeAPI.identify && window.WalkMeAPI.identify(window._walkmeInternals.Segment);
};

WalkMe.prototype.reset = function () {
  window._walkMe && window._walkMe.removeWalkMe && window._walkMe.removeWalkMe();
}

==> analytics.js-integration-walkme-1.0.2.tgz: package/lib/index.js <==
'use strict';

/**
 * Module dependencies.
 */

var integration = require('@segment/analytics.js-integration');
var Identify = require('segmentio-facade').Identify;

/**
 * Expose `WalkMe`
 */

var WalkMe = module.exports = integration('WalkMe')
  .assumesPageview()
  .global('walkme')
  .option('walkMeSystemId', '')
  .option('walkMeEnvironment', '')
  .option('walkMeLoadInIframe', false)
  .tag('<script src="https://cdn.walkme.com/users/{{ walkMeSystemId }}{{ walkMeEnvironment }}/walkme_{{ walkMeSystemId }}_https.js">')

/**
 * Initialize WalkMe
 *
 * @param {Facade} page
 */

WalkMe.prototype.initialize = function () {
  window._walkmeConfig = { smartLoad: true };

  if (this.options.walkMeLoadInIframe) {
    window.walkme_load_in_iframe = true;
  }

  var env = "\/" + (this.options.walkMeEnvironment && this.options.walkMeEnvironment.toLowerCase());

  if (!env || env == "\/" || env == "\/production") {
    env = "";
  }

  var _this = this;
  window.walkme_ready = function () {
    _this.ready();
  };

  this.load({
    walkMeSystemId: this.options.walkMeSystemId.toLowerCase(),
    walkMeEnvironment: env
  });

};

/**
 * Has the WalkMe library been loaded yet?
 *
 * @return {Boolean}
 */

WalkMe.prototype.loaded = function () {
  return !!window.WalkMeAPI;
};

/**
 * Identify.
 *
 * @api public
 * @param {Identify} identify
 */

WalkMe.prototype.identify = function (identify) {
  window._walkmeInternals.Segment = window._walkmeInternals.Segment || {}

  if (identify.userId()) {
    window._walkmeInternals.Segment.userId = String(identify.userId());
    window._walkmeInternals.Segment.isAnonUser = false;
  } else {
    window._walkmeInternals.Segment.userId = String(identify.anonymousId());
    window._walkmeInternals.Segment.isAnonUser = true;
  }

  window._walkmeInternals.Segment.email = identify.email();
  window._walkmeInternals.Segment.traits = identify.traits();

  window.WalkMeAPI.identify && window.WalkMeAPI.identify(window._walkmeInternals.Segment);
};

WalkMe.prototype.reset = function () {
  window._walkMe && window._walkMe.removeWalkMe && window._walkMe.removeWalkMe();
}
